<?php
/**
 * 2018 Cenový automat (www.cenovyautomat.cz)
 * PrestaShop module pro propojení se službou Cenový automat
 *
 * NOTICE OF LICENSE
 *
 * This software is provided as is, without warranty of any kind.
 * The author shall not be liable for damages of any kind.
 * Use of this software indicates that you agree.
 *
 * Tento software je poskytován tak, jak je, bez záruky jakéhokoli druhu.
 * Autor nenese odpovědnost za škody jakéhokoliv druhu.
 * Používáním tohoto softwaru znamená,že souhlasíte s výše uvedenými autorskými právy.
 *
 * DISCLAIMER
 *
 * Please do not change this text, remove the link or remove all or any part
 * of the creator copyright notice
 * Please also note that although you are allowed to make modificationsf or your
 * own personal use, you may not distribute the original or the modified code
 * without permission.
 *
 * Prosím, neměňte tento text, nemazejte odkazy, neodstraňujte části a nebo celé
 * oznámení těchto autorských práv.
 * Prosím vezměte také na vědomí, že i když máte možnost provádět změny pro vlastní
 * osobní potřebu,nesmíte distribuovat původní nebo upravený kód bez povolení.
 *
 * @author     Cenový automat <info@cenovyautomat.cz>
 * @copyright  2018 Cenový automat (www.cenovyautomat.cz)
 * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 * @version    1.1.0 [Nov. 2018]
 */

// read and decode the json input
$input = fopen('php://input', 'r');
$response = json_decode(stream_get_contents($input), true);
fclose($input);
// include Prestashop
require(dirname(__FILE__).'/../../config/config.inc.php');
require(dirname(__FILE__).'/../../init.php');

//get keys from module configuration
$cryptoKey = Configuration::get('CENOVY_AUTOMAT_CRYPTO_KEY');
$apiKey = Configuration::get('CENOVY_AUTOMAT_API_KEY');

// check the apiKey, if not correct, die
if ($response['content']['apiKey'] != $apiKey){
    http_response_code(401);
    ob_flush();
    die();
}

//check the hash of the request, if not correct, die
if ($response['hash'] != hash_hmac('sha512', json_encode($response['content']), $cryptoKey)){
    http_response_code(400);
    ob_flush();
    die();
}

if ($response['content']['action'] !='') {

    switch ($response['content']['action']) {

        case 'test':
            http_response_code(200);
            echo "Test OK";
            break;

        case 'getWholesalePrice':
            if (isset($response['content']['id'])) {
                $product = new Product($response['content']['id']);
                //if $product->id is not empty, we found product
                //otherwise product was not found, we created a new product object, error
                if ($product->id != ''){
                    $price = $product->wholesale_price * (1+($product->getTaxesRate(new Address($address))/100));
                    $price = openssl_encrypt($price, 'aes-128-cbc', $cryptoKey);
                    $content['content']['price'] = $price;
                    $content['content']['apiKey'] = $apiKey;
                    $content['hash'] = hash_hmac('sha512', json_encode($content['content']), $cryptoKey);
                    $content = json_encode($content);
                    http_response_code(200);
                    echo $content;
                } else {
                    http_response_code(404);
                    echo "Product with given ID not found";
                }
            } else {
                http_response_code(400);
                echo "Product ID not specified";
            }
            break; //getWholesalePrice

        case 'setPrice':
            if (isset($response['content']['id'])) {
                $product = new Product($response['content']['id'], true);
                //if $product->id is not empty, we found product
                //otherwise product was not found, we created a new product object, error
                if ($product->id != ''){
                    $price = (float)$response['content']['price'];
                    $price = $price / (1+($product->getTaxesRate(new Address($address))/100));

                    //check if exist special price in PrestaShop
                    if ($product->specificPrice){
                        $specificPrice = new SpecificPriceCore($product->specificPrice['id_specific_price']);
                        switch ($product->specificPrice['reduction_type']){
                            case 'percentage':
                                //discount by %
                                $specificPrice->reduction = 1-($price/$product->price);
                                break;
                            case 'amount':
                                //discount by ammount
                                if ($product->specificPrice['price'] == -1){
                                    //Ponechat základní cenu zaškrtnuto
                                    $specificPrice->reduction = $product->base_price - $price ;
                                    $specificPrice->reduction += $product->specificPrice['reduction_tax'] * $specificPrice->reduction * ($product->getTaxesRate(new Address($address))/100);
                                } else {
                                    //Ponechat základní cenu NEzaškrtnuto
                                    $specificPrice->reduction = $product->specificPrice['price'] - $price ;
                                    $specificPrice->reduction += $product->specificPrice['reduction_tax'] * $specificPrice->reduction * ($product->getTaxesRate(new Address($address))/100);
                                }
                                break;
                        }

                        $specificPrice->reduction = round($specificPrice->reduction, 6);
                        //specificPrice can't be < 0, if the CA want to setup higher price than base price, set reduction to 0, otherwise PS will generate error
                        if ($specificPrice->reduction < 0){
                            $specificPrice->reduction = 0;
                        }

                        $specificPrice->price = round($specificPrice->price, 6);
                        $success = $specificPrice->update();
                    } else {
                        $product->price = round($price, 6);
                        $success = $product->save();
                    }


                    if ($success){
                        http_response_code(200);
                        echo 'Price succesfully set';
                    } else {
                        http_response_code(400);
                        echo 'Price was not set';
                    }
                } else {
                    http_response_code(404);
                    echo "Product with given ID not found";
                }
            } else {
                http_response_code(400);
                echo "Product ID not specified";
            }
            break; //setPrice

        default:
            http_response_code(400);
            echo "Invalid action";
            break;
    }
} else {
    http_response_code(400);
    echo "Action not specified";
}
