<?php
/**
 * 2010 Cenový automat (www.cenovyautomat.cz)
 *
 * NOTICE OF LICENSE
 *
 * This software is provided as is, without warranty of any kind.
 * The author shall not be liable for damages of any kind.
 * Use of this software indicates that you agree.
 *
 * Tento software je poskytován tak, jak je, bez záruky jakéhokoli druhu.
 * Autor nenese odpovědnost za škody jakéhokoliv druhu.
 * Používáním tohoto softwaru znamená,že souhlasíte s výše uvedenými autorskými právy.
 *
 * DISCLAIMER
 *
 * Please do not change this text, remove the link or remove all or any part
 * of the creator copyright notice
 * Please also note that although you are allowed to make modificationsf or your
 * own personal use, you may not distribute the original or the modified code
 * without permission.
 *
 * Prosím, neměňte tento text, nemazejte odkazy, neodstraňujte části a nebo celé
 * oznámení těchto autorských práv.
 * Prosím vezměte také na vědomí, že i když máte možnost provádět změny pro vlastní
 * osobní potřebu,nesmíte distribuovat původní nebo upravený kód bez povolení.
 *
 * @author     Cenový automat <info@cenovyautomat.cz>
 * @copyright  2018 Cenový automat (www.cenovyautomat.cz)
 * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 * @version    1.1.0 [Nov. 2018]
 */

if (!defined('_PS_VERSION_'))
    exit;

class CenovyAutomat extends Module
{
    public function __construct()
    {
        $this->name = 'cenovyautomat';
        $this->tab = 'others';
        $this->version = '1.1.0';
        $this->author = 'CenovyAutomat.cz';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = array('min' => '1.5', 'max' => _PS_VERSION_);
        $this->bootstrap = false;

        parent::__construct();

        $this->displayName = $this->l('Cenový automat');
        $this->description = $this->l('Modul pro propojení se službou cenovyautomat.cz.');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');

        if (!Configuration::get('CENOVY_AUTOMAT_API_KEY'))
            $this->warning = $this->l('API klíč není zadán');

        if (!Configuration::get('CENOVY_AUTOMAT_CRYPTO_KEY'))
            $this->warning = $this->l('Šifrovací klíč není zadán');
    }



    public function install()
    {
        if (!parent::install()
            || !extension_loaded('openssl')      //openssl is required
            || version_compare(PHP_VERSION, '5.4.0') < 0) { //PHP 5.4.0 and higher required
            return false;
        }
        return true;
    }


    public function uninstall()
    {

        if (!parent::uninstall() || !Configuration::deleteByName('CENOVY_AUTOMAT_API_KEY')  ||  !Configuration::deleteByName('CENOVY_AUTOMAT_CRYPTO_KEY')) {
            return false;
        }
        return true;
    }


    public function getContent()
    {
        $output = null;

        if (Tools::isSubmit('submit'.$this->name)) {
            $apiKey = Tools::getValue('CENOVY_AUTOMAT_API_KEY');
            $cryptoKey = Tools::getValue('CENOVY_AUTOMAT_CRYPTO_KEY');
            if (!$apiKey || empty($apiKey) || !Validate::isGenericName($apiKey) || !$cryptoKey || empty($cryptoKey) || !Validate::isGenericName($cryptoKey)  ) {
                $output .= $this->displayError($this->l('Nepovolená konfigurační hodnota'));
            } else {
                Configuration::updateValue('CENOVY_AUTOMAT_API_KEY', trim($apiKey));
                Configuration::updateValue('CENOVY_AUTOMAT_CRYPTO_KEY', trim($cryptoKey));
                $output .= $this->displayConfirmation($this->l('Nastavení uloženo'));
            }
        }
        return $output.$this->displayForm();
    }


    public function displayForm()
    {
        // Get default language
        $default_lang = (int)Configuration::get('PS_LANG_DEFAULT');

        // Init Fields form array
        $fields_form[0]['form'] = array(
            'legend' => array(
                'title' => $this->l('Zadejte API klíč a Šifrovací klíč, jak jsou uvedenév aplikaci z Cenový automat v Konfigurace - Export/Import.').'</br></br>',
            ),
                'input' => array(
                array(
                    'type' => 'text',
                    'label' => $this->l('API klíč'),
                    'name' => 'CENOVY_AUTOMAT_API_KEY',
                    'size' => 32,
                    'required' => true
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Šifrovací klíč'),
                    'name' => 'CENOVY_AUTOMAT_CRYPTO_KEY',
                    'size' => 32,
                    'required' => true
                )
            ),

            'submit' => array(
                'title' => $this->l('Save'),
                'class' => 'button'
            )
        );

        $helper = new HelperForm();

        // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;

        // Language
        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;

        // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = true;        // false -> remove toolbar
        $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
        $helper->submit_action = 'submit'.$this->name;
        $helper->toolbar_btn = array(
            'save' =>
                array(
                    'desc' => $this->l('Save'),
                    'href' => AdminController::$currentIndex.'&configure='.$this->name.'&save'.$this->name.
                        '&token='.Tools::getAdminTokenLite('AdminModules'),
                ),
            'back' => array(
                'href' => AdminController::$currentIndex.'&token='.Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->l('Back to list')
            )
        );

        // Load current value
        $helper->fields_value['CENOVY_AUTOMAT_API_KEY'] = Configuration::get('CENOVY_AUTOMAT_API_KEY');
        $helper->fields_value['CENOVY_AUTOMAT_CRYPTO_KEY'] = Configuration::get('CENOVY_AUTOMAT_CRYPTO_KEY');
        return $helper->generateForm($fields_form);
    }
}
